/*
 * Create a list of all fonts contained in a PDF document and check if they are
 * embedded.
 *
 * Required software: pCOS interface 8 (PDFlib+PDI/PPS 9, TET 4.1, PLOP 5.0)
 * Required data: PDF document
 */
package com.pdflib.cookbook.pcos.pages;

import com.pdflib.IpCOS;
import com.pdflib.cookbook.pcos.pcos_cookbook_example;

public class page_fonts extends pcos_cookbook_example {

    /* This is where the data files are. Adjust as necessary. */
    private final static String SEARCH_PATH = "../input";

    public void example_code(IpCOS p, int doc) throws Exception {

        System.out.println("File name: " + p.pcos_get_string(doc, "filename"));

        int pagecount = (int) p.pcos_get_number(doc, "length:pages");

        for (int page = 0; page < pagecount; page++) {
            /* retrieve the number of fonts on the page */
            int fontcount = (int) p.pcos_get_number(doc, "length:pages[" + page
                + "]/fonts");

            if (fontcount > 0) {
                System.out.println("Page " + (page + 1) + ": " + fontcount + " font(s) found");

                for (int i = 0; i < fontcount; i++) {
                    System.out.print("    ");
                    System.out.print(p.pcos_get_string(doc, "pages[" + page
                        + "]/fonts[" + i + "]/name"));
                    boolean embedded = p.pcos_get_number(doc, "pages[" + page
                        + "]/fonts[" + i + "]/embedded") != 0;
                    if (embedded)
                        System.out.println(" (embedded)");
                    else
                        System.out.println(" (not embedded)");
                }
            }
        }
    }

    public page_fonts(String[] argv, String readable_name, String search_path) {
        super(argv, readable_name, search_path);
    }

    public static void main(String argv[]) {
        page_fonts example = new page_fonts(argv, "Fonts", SEARCH_PATH);
        example.execute();
    }
}
